@@ -5,17 +5,11 @@ from inspect import isclass
 import pkg_resources
 from jsonschema import validate
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 
 _SCHEMA_PATH = 'schema.json'
 
 
-class Label:
-    MODEL = 'model'
-    DATA = 'data'
-    FILTER = 'filter'
-
-
 def validate_entities(entities):
     schema_res = pkg_resources.resource_string('sqlalchemyseed', _SCHEMA_PATH)
     schema = json.loads(schema_res)
@@ -71,6 +65,9 @@ class Seeder:
         self.object_instances = []
 
     def seed(self, entities, session=None):
+        validate_entities(entities)
+        self.object_instances = []
+
         if isinstance(entities, dict):
             self._entity(entities)
         elif isinstance(entities, list):
